import { IClearResponse, TWorkerMessage } from 'worker-timers-worker';
export declare const isClearResponse: (message: TWorkerMessage) => message is IClearResponse;
//# sourceMappingURL=clear-response.d.ts.map