import { ICallNotification, TWorkerMessage } from 'worker-timers-worker';
export declare const isCallNotification: (message: TWorkerMessage) => message is ICallNotification;
//# sourceMappingURL=call-notification.d.ts.map