export declare const load: (url: string) => {
    clearInterval: (timerId: number) => void;
    clearTimeout: (timerId: number) => void;
    setInterval: (func: Function, delay?: number) => number;
    setTimeout: (func: Function, delay?: number) => number;
};
//# sourceMappingURL=module.d.ts.map